OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Visor de fitxers senzill amb presentació de diapositives per a contingut multimèdia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Vegeu les fotografies i vídeos de les darreres vacances com a les pel·lícules, doneu un cop d'ull a la darrera novel·la des del Nextcloud, escolliu el millor GIF de la vostra col·lecció gràcies a la previsualització dels fitxers preferits i molt més!",
    "Your browser does not support audio." : "El vostre navegador no és compatible amb l'àudio.",
    "Error loading {name}" : "S'ha produït un error en carregar {name}",
    "Image saved" : "S'ha desat la imatge",
    "Error saving image" : "S'ha produït un error en desar la imatge",
    "Unsaved changes" : "Hi ha canvis sense desar",
    "Drop changes" : "Suprimeix els canvis",
    "Play the live photo" : "Reprodueix la fotografia en viu",
    "LIVE" : "DIRECTE",
    "Your browser does not support videos." : "El vostre navegador no és compatible amb els vídeos.",
    "This file no longer exists" : "Aquest fitxer ja no existeix",
    "There is no plugin available to display this file type" : "No hi ha cap connector disponible per a mostrar aquest tipus de fitxer",
    "Edit" : "Edita",
    "Exit full screen" : "Surt de la pantalla completa",
    "Full screen" : "Pantalla completa",
    "Open sidebar" : "Obre la barra lateral",
    "Download" : "Baixa",
    "Delete" : "Suprimeix",
    "View" : "Visualitza",
    "Name" : "Nom",
    "Save" : "Desa",
    "Save as" : "Anomena i desa",
    "Back" : "Torna",
    "Loading …" : "S'està carregant…",
    "Reset" : "Reinicialitza",
    "All changes will be lost." : "Tots els canvis es perdran.",
    "Are you sure you want to continue?" : "Segur que voleu continuar?",
    "Cancel" : "Cancel·la",
    "Apply" : "Aplica",
    "Warning" : "Avís",
    "Confirm" : "Confirma",
    "Discard changes" : "Descarta els canvis",
    "Undo" : "Desfés",
    "Redo" : "Refés",
    "Show original image" : "Mostra la imatge original",
    "Zoom in" : "Amplia",
    "Zoom out" : "Allunya",
    "Toggle zoom menu" : "Commuta el menú de zoom",
    "Adjust" : "Ajusta",
    "Fine-tune" : "Afina",
    "Filters" : "Filtres",
    "Watermark" : "Marca d'aigua",
    "Draw" : "Dibuixa",
    "Resize" : "Redimensiona",
    "Image name" : "Nom de la imatge",
    "Invalid image." : "La imatge no és vàlida.",
    "Error while uploading the image." : "S'ha produït un error en pujar la imatge.",
    "are not images" : "no són imatges",
    "is not an image" : "no és una imatge",
    "to be uploaded" : "per pujar",
    "Crop" : "Retalla",
    "Original" : "Original",
    "Custom" : "Personalitzat",
    "Square" : "Quadrat",
    "Landscape" : "Apaïsat",
    "Portrait" : "Vertical",
    "Ellipse" : "El·lipse",
    "Classic TV" : "Televisor clàssic",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Fletxa",
    "Blur" : "Difumina",
    "Brightness" : "Brillantor",
    "Contrast" : "Contrast",
    "Un-flip X" : "Descapgira X",
    "Flip X" : "Capgira X",
    "Un-flip Y" : "Descapgira Y",
    "Flip Y" : "Capgira Y",
    "HSV" : "HSV",
    "Hue" : "Tonalitat",
    "Saturation" : "Saturació",
    "Value" : "Valor",
    "Image" : "Imatge",
    "Importing …" : "S'està important…",
    "+ Add image" : "+ Afegeix una imatge",
    "Upload image" : "Pujada d'una imatge",
    "From gallery" : "De la galeria",
    "Line" : "Línia",
    "Pen" : "Llapis",
    "Polygon" : "Polígon",
    "Sides" : "Cares",
    "Rectangle" : "Rectangle",
    "Corner Radius" : "Radi de la cantonada",
    "Width in pixels" : "Amplada en píxels",
    "Height in pixels" : "Alçada en píxels",
    "Toggle ratio lock" : "Canvia la relació d'aspecte",
    "Reset to original image size" : "Reinicialitza la mida de la imatge original",
    "Rotate" : "Gira",
    "Text" : "Text",
    "Text spacing" : "Espaiat del text",
    "Text alignment" : "Alineació del text",
    "Font family" : "Família tipogràfica",
    "Size" : "Mida",
    "Letter spacing" : "Espaiat de la lletra",
    "Line height" : "Alçada de la línia",
    "Warmth" : "Calidesa",
    "+ Add watermark" : "+ Afegeix una marca d'aigua",
    "+ Add text watermark" : "+ Afegeix una marca d'aigua de text",
    "Choose watermark type" : "Trieu el tipus de marca d'aigua",
    "Upload watermark" : "Pujar una marca d'aigua",
    "Add as text" : "Afegeix com a text",
    "Padding" : "Farciment",
    "Paddings" : "Separacions",
    "Shadow" : "Ombra",
    "Horizontal" : "Horitzontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacitat",
    "Transparency" : "Transparència",
    "Position" : "Posició",
    "Stroke" : "Traç",
    "Save image as" : "Anomena i desa la imatge",
    "Extension" : "Extensió",
    "Format" : "Format",
    "Name is required." : "El nom és obligatori.",
    "Quality" : "Qualitat",
    "Saved image size (width x height)" : "Mida de la imatge desada (amplada x alçada)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Tingueu en compte que l'àrea de retall seleccionada és inferior al canvi de mida aplicat, fet que pot provocar una disminució de la qualitat",
    "Actual size (100%)" : "Mida real (100%)",
    "Fit size" : "Mida ajustada",
    "Select image to add …" : "Seleccioneu la imatge per afegir …",
    "Failed to load image." : "No s'ha pogut carregar la imatge.",
    "Menu" : "Menú",
    "Width" : "Amplada",
    "Height" : "Alçada",
    "No preview available for this crop item" : "No hi ha cap previsualització disponible per a aquest element retallat"
},
"nplurals=2; plural=(n != 1);");
